Summary:	A GNU file archiving program
Name:		tar
Version:	1.33
Release:	%mkrel 2
License:	GPLv3
Group:		Archiving/Backup
URL:		http://www.gnu.org/software/tar/tar.html
Source0:	ftp://ftp.gnu.org/gnu/tar/%{name}-%{version}.tar.xz
Source1:	ftp://ftp.gnu.org/gnu/tar/%{name}-%{version}.tar.xz.sig
Source2:	%{name}-help2man.bz2
Patch0:		tar-1.30-fix-buffer-overflow.patch
Patch1:		tar-1.33-lzma.patch
Patch2:		tar-1.33-Actually-prefer-dev-full-over-dev-null-as-a-replacement-for-stdin.patch
BuildRequires:	bison
BuildRequires:	xz
BuildRequires:	texinfo
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(libacl)

# Required for the checks
BuildRequires:	attr
BuildRequires:	acl
BuildRequires:	policycoreutils


%description
The GNU tar program saves many files together into one archive and
can restore individual files (or all of the files) from the archive.
Tar can also be used to add supplemental files to an archive and to
update or list files in the archive.

Tar includes multivolume support, automatic archive compression/
decompression, the ability to perform remote archives and the
ability to perform incremental and full backups.

If you want to use Tar for remote backups, you'll also need to
install the rmt package.

You should install the tar package, because you'll find its
compression and decompression utilities essential for working
with files.

%prep
%setup -q
%patch0 -p0
%patch1 -p0
%patch2 -p1

bzcat %{SOURCE2} > ./help2man
chmod +x ./help2man

xz ChangeLog

# (misc, 02-11-2010, sigpipe test do not pass on iurt )
sed -i 's/.*sigpipe.at.*//' tests/testsuite.at

# (kekepower, 2019-01-04, dirrem01 and dirrem02 fails on iurt)
sed -i 's/.*dirrem01.*//' tests/testsuite.at
sed -i 's/.*dirrem02.*//' tests/testsuite.at

rm -f tests/testsuite

%build
autoreconf -vfi
%configure \
	--enable-backup-scripts \
	--with-lzma="xz --format=lzma" \
	DEFAULT_RMT_DIR=%{_sbindir} \
	--disable-rpath \
	RSH=/usr/bin/ssh

%make_build

# thanks to diffutils Makefile rule
(echo '[NAME]' && sed 's@/\* *@@; s/-/\\-/; q' src/tar.c) | (./help2man -i - -S '%{name} %{version}' src/tar ) | sed 's/^\.B info .*/.B info %{name}/' > %{name}.1

%check
%__make check

%install
%make_install

ln -sf tar %{buildroot}%{_bindir}/gtar

install -D -m 644 tar.1 %{buildroot}%{_mandir}/man1/tar.1

# conflicts with coda-debug-backup
mv %{buildroot}%{_sbindir}/backup %{buildroot}%{_sbindir}/tar-backup
mv %{buildroot}%{_sbindir}/restore %{buildroot}%{_sbindir}/tar-restore

# rmt is provided by rmt ...
mv %{buildroot}%{_sbindir}/rmt %{buildroot}%{_sbindir}/rmt-tar
mv %{buildroot}%{_mandir}/man8/rmt.8 %{buildroot}%{_mandir}/man8/rmt-tar.8

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS ChangeLog.xz NEWS README THANKS TODO
%{_bindir}/*
%{_libexecdir}/backup.sh
%{_libexecdir}/dump-remind
%{_sbindir}/*
%{_infodir}/*.info*
%{_mandir}/man?/*


%changelog
* Fri Jan 08 2021 tmb <tmb> 1.33-2.mga8
+ Revision: 1669832
- Actually prefer /dev/full over /dev/null as a replacement for stdin

* Fri Jan 08 2021 luigiwalser <luigiwalser> 1.33-1.mga8
+ Revision: 1669728
- 1.33
- rework patch 1

* Wed Apr 15 2020 joequant <joequant> 1.32-3.mga8
+ Revision: 1567673
- rebuild to remove info-install dep

* Sat Feb 15 2020 umeabot <umeabot> 1.32-2.mga8
+ Revision: 1523186
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Feb 23 2019 kekepower <kekepower> 1.32-1.mga7
+ Revision: 1369624
- Update to version 1.32

* Fri Jan 04 2019 kekepower <kekepower> 1.31-1.mga7
+ Revision: 1348979
- Update to version 1.31 to fix CVE-2018-20482 (mga#24117)
- Remove merged Patch2

* Mon Sep 03 2018 tv <tv> 1.30-3.mga7
+ Revision: 1256369
- rely on filetriggers for info system (mga#23482)

* Fri Apr 20 2018 daviddavid <daviddavid> 1.30-2.mga7
+ Revision: 1220380
- new version: 1.30
- rename and rediff fix-buffer-overflow patch
- remove merged upstream patch

* Thu Sep 07 2017 joequant <joequant> 1.29-4.mga7
+ Revision: 1151756
- update to new gcc/binutils

* Wed Nov 16 2016 neoclust <neoclust> 1.29-3.mga6
+ Revision: 1067523
- Add P2: Fix CVE-2016-6321

* Sat May 21 2016 luigiwalser <luigiwalser> 1.29-2.mga6
+ Revision: 1017377
- fix incorrectly rediffed patch1
+ shlomif <shlomif>
- Remove old patches

* Tue May 17 2016 yuri_myasoedov <yuri_myasoedov> 1.29-1.mga6
+ Revision: 1016500
- update to new version 1.29.
- update patches.
- replace %%makeinstall_std with %%make_install.
- replace %%make with %%make_build.

* Fri Feb 12 2016 umeabot <umeabot> 1.28-5.mga6
+ Revision: 958977
- Mageia 6 Mass Rebuild

* Fri Aug 21 2015 tmb <tmb> 1.28-4.mga6
+ Revision: 867900
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 1.28-3.mga5
+ Revision: 748813
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.28-2.mga5
+ Revision: 689693
- Mageia 5 Mass Rebuild

* Wed Jul 30 2014 luigiwalser <luigiwalser> 1.28-1.mga5
+ Revision: 658373
- 1.28
- fix typo in lzma patch
- BR texinfo for makeinfo command
- remove ancient conflicts
- look for rmt command in the correct location
- UsrMove-related SPEC fixes
- fix rmt-tar man page name

* Wed Dec 11 2013 shlomif <shlomif> 1.27.1-1.mga4
+ Revision: 556257
- New version 1.27.1

* Mon Oct 21 2013 umeabot <umeabot> 1.27-2.mga4
+ Revision: 539656
- Mageia 4 Mass Rebuild
+ shlomif <shlomif>
- Remove old patch

* Mon Oct 07 2013 shlomif <shlomif> 1.27-1.mga4
+ Revision: 492674
- New version 1.27

* Mon Jan 14 2013 umeabot <umeabot> 1.26-4.mga3
+ Revision: 384040
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 pterjan <pterjan> 1.26-3.mga3
+ Revision: 340121
- Fix for _libdir != _libexecdir

* Wed Dec 05 2012 cjw <cjw> 1.26-2.mga3
+ Revision: 327044
- patch2: fix build error with glibc 2.16

* Wed Apr 13 2011 tv <tv> 1.26-1.mga2
+ Revision: 84589
- new release

* Sat Jan 08 2011 blino <blino> 1.25-1.mga1
+ Revision: 543
- imported package tar


* Sat Nov 27 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.25-1mdv2011.0
+ Revision: 601819
- update to 1-25
- remove patches applied upstream
- rediff patch (fix buffer overflow)

* Tue Nov 02 2010 Michael Scherer <misc@mandriva.org> 1.24-4mdv2011.0
+ Revision: 592108
- disable a test that do not work ( sigpipe, no time to look )
- fix for the device creation problem that broke iurt and the cluster
- re-enable tests
- reenable the tests suite, so unforeseen breakage do not pass

* Wed Oct 27 2010 Anssi Hannula <anssi@mandriva.org> 1.24-3mdv2011.0
+ Revision: 589646
- fix regression with -C and extracting directories (patch from upstream)

* Tue Oct 26 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.24-2mdv2011.0
+ Revision: 589451
- remove p0, merged upstream.
- new version 1.24
- rediff mdv lzma patch
- add a patch from gentoo to fix #61419 (thanks oden)
- bump release, for override last commit
- rever last commit.

* Mon Oct 25 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.24-1mdv2011.0
+ Revision: 589298
- remove p0, p1: merged upstream.
- new version 1.24

* Mon Jul 19 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.23-4mdv2011.0
+ Revision: 554994
- P1: fix mdvbug #60251

* Mon Mar 22 2010 Oden Eriksson <oeriksson@mandriva.com> 1.23-3mdv2010.1
+ Revision: 526624
- rebuilt due to lack of space on n5 in the bs
- added br on rsh due to a long standing missing dep

* Wed Mar 10 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.23-1mdv2010.1
+ Revision: 517607
- rediff patch
- update to 1.23

* Fri Sep 25 2009 Thomas Backlund <tmb@mandriva.org> 1.22-2mdv2010.0
+ Revision: 448752
- We have had the -Y flag for lzma since atleast 2008.0
  Add back the flag so we dont break userspace on upgrades
  (added with note that it's depreceated)

* Thu Sep 24 2009 Olivier Blin <oblin@mandriva.com> 1.22-1mdv2010.0
+ Revision: 448165
- explicitely buildrequire xz (from Arnaud Patard)
- remove xz patch (merged upstream in 1.22)

  + Thierry Vignaud <tv@mandriva.org>
    - use upstream bz2 tarball
    - fix URL

  + Funda Wang <fwang@mandriva.org>
    - New version 1.22

* Thu Feb 26 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.21-2mdv2009.1
+ Revision: 345103
- since package is of GPLv3 license which comes with common-licenses package,
  we'll just drop shipping COPYING with the package
- might as well compress the changelog with xz in stead of bzip2 to save a few
  more kilobytes.. :p
- add xz support using -J switch which upstream seems plan on using, but
  prematurely introduced to support older revision of new format judging by
  magic used.. (replaces old lzma patch, P0)

* Sun Dec 28 2008 Oden Eriksson <oeriksson@mandriva.com> 1.21-1mdv2009.1
+ Revision: 320310
- 1.21
- fix the lzma patch; note that upstrean chose -J but mandriva use -Y,
  mandriva should adjust accordingly..., and then nuke the lzma patch

* Mon Dec 22 2008 Oden Eriksson <oeriksson@mandriva.com> 1.20-8mdv2009.1
+ Revision: 317662
- rebuild

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 1.20-7mdv2009.0
+ Revision: 265746
- rebuild early 2009.0 package (before pixel changes)

* Wed Apr 23 2008 Adam Williamson <awilliamson@mandriva.org> 1.20-6mdv2009.0
+ Revision: 196832
- disable tests as they randomly fail when building on the bs
- revert to the previous LZMA patch (rediffed) as the code merged upstream doesn't work right

* Thu Apr 17 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.20-2mdv2009.0
+ Revision: 195385
- add missing buildrequire on bison
- new version
- fix license
- drop patches 13 and 14, both were merged upstream

* Thu Feb 07 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.19-2mdv2008.1
+ Revision: 163377
- Fix compression of tar.bz2 files returning error code 2 (ubuntu)(Bug #35291 #37194)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - restore previous version

* Tue Oct 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.19-1mdv2008.1
+ Revision: 98756
- new version
- drop patch 15 (merged upstream)
- nuke rpath
- spec file clean

* Mon Sep 10 2007 Thierry Vignaud <tv@mandriva.org> 1.18-2mdv2008.0
+ Revision: 84081
- patch 15: security fix for CVE-2007-4131
- drop patch 11 which prevents patch 15 from working properly and isn't proper
  to begin with

* Sat Jun 30 2007 Funda Wang <fwang@mandriva.org> 1.18-1mdv2008.0
+ Revision: 46067
- New version


* Mon Feb 12 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 1.16-3mdv2007.1
+ Revision: 118886
- update to use 'lzma' over deprecated 'lzmash' wrapper script

* Wed Nov 29 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.16-2mdv2007.1
+ Revision: 88709
- bump release
- patch 14: security fix for MDKSA-2006:219 (#27379)

* Thu Nov 23 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.16-1mdv2007.1
+ Revision: 86832
- Import tar

* Thu Nov 23 2006 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.16-1mdv2007.1
- new release

* Fri Jun 30 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 1.15.91-1mdv2007.0
- 1.15.91
- fix make-check-outside-check-section
- regenerate P13
- update url

* Sat May 13 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.15.90-2mdk
- patch 13: fix segfault (#22434)

* Fri May 12 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.15.90-1mdk
- new release
- kill patches 1, 7, 12 (uneeded)
- rediff patch 13

* Wed Feb 22 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.15.1-8mdk
- patch 14: security fix for CVE-2006-0300
- use %%mkrel

* Sun Jan 08 2006 Giuseppe Ghibò <ghibo@mandriva.cm> 1.15.1-7mdk
- Added supporto for lzmash compression (tar -Y).

* Sun Jan 01 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 1.15.1-6mdk
- Rebuild

* Thu Aug 25 2005 Pixel <pixel@mandriva.com> 1.15.1-5mdk
- get rid of ChangeLog.1 (ie prior to 1997)
- compress ChangeLog

* Wed Jul 20 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 1.15.1-4mdk
- Remove alternative install for rmt, use /sbin/rmt from dump

* Tue Jul 19 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 1.15.1-3mdk
- Fix postun alternative install for rmt
- Fix compilation with gcc 4 (patch 12)

* Tue Feb 22 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.15.1-2mdk
- fix packages ordering at install time (#13792)

* Wed Dec 22 2004 Abel Cheung <deaddog@mandrakesoft.com> 1.15.1-1mdk
- New release 1.15.1

* Wed Dec 22 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.15-1mdk
- 1.15
- regenerate P7

* Tue May 25 2004 Abel Cheung <deaddog@deaddog.org> 1.14-1mdk
- New version
- Drop P105 (-y/-I), since -j/--bzip2 is stabilized and well known now
- Drop P0, use help2man to generate manpage instead of bundling 4-yr-old one
- Drop P8, P10 (upstream)
- Rediff P1, P7, P11
- Install scripts as well
- Use alternative for rmt

